SeoKey class

Inheritance

Constructors

SeoKey(TagType tagType, {String text = "", String src = "", String alt = "", String? className, Map<String, String>? attributes})

Properties

alt → String
final
attributes → Map<String, String>
final
className → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → String
image일 때 url
final
tagType → TagType
final
text → String
final
value → String
The value to which this key delegates its operator==.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited